/*
 * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
 *
 * Squid software is distributed under GPLv2+ license and includes
 * contributions from numerous individuals and organizations.
 * Please see the COPYING and CONTRIBUTORS files for details.
 */

#ifndef SQUID_SRC_PROTOS_H
#define SQUID_SRC_PROTOS_H

void shut_down(int);
void rotate_logs(int);
void reconfigure(int);

#endif /* SQUID_SRC_PROTOS_H */

